@@ -37,7 +37,7 @@ use File::Spec::Functions qw(catfile catpath splitpath);
 use Git::Repository;
 use TryCatch;
 
-use constant debstdversion => '4.5.1';
+use constant debstdversion => '4.6.2';
 
 our %DEFAULTS = (
 );
@@ -104,8 +104,12 @@ sub get_email {
 
     $email ||= ( $ENV{DEBEMAIL} || $ENV{EMAIL} );
     unless ($email) {
-	my $mailh;
-        chomp( $mailh = `cat /etc/mailname` );
+        my $mailh;
+        if ( -e "/etc/mailname" ) {
+            chomp( $mailh = `cat /etc/mailname` );
+        } else {
+            chomp($mailh=`hostname --fqdn 2>/dev/null || hostname --short 2>/dev/null || echo "localhost"`)
+        }
         $email = $self->get_user . '@' . $mailh;
     }
 
@@ -117,18 +121,21 @@ sub get_name {
     my $self = shift;
 
     my $name;
-    my $user = $self->get_user;
-    my $pwnam = getpwuid($<);
-    die "Cannot determine current user\n" unless $pwnam;
     if ( defined $ENV{DEBFULLNAME} ) {
         $name = $ENV{DEBFULLNAME};
+    } else {
+        my $pwname = getpwuid($<);
+        if ( $pwname ) {
+            $name = ($pwname)[6];
+            if ( $name ) {
+                $name =~ s/,.*//;
+            }
+        }
     }
-    else {
-        $name = $pwnam->gecos;
-        $name =~ s/,.*//;
+    unless ( $name ) {
+        print "I: Cannot determine your fullname (set DEBFULLNAME)\n";
+        $name="Unknown";
     }
-    $user ||= $pwnam->name;
-    $name ||= $user;
     return $name;
 }
 
@@ -455,12 +462,12 @@ sub create_watch {
 version=4
 opts="filenamemangle=s/(?:.*?)?v?(\\d[\\d.]*)\\.tar\\.gz/$project-\$1.tar.gz/" \\
     https://github.com/$user/$project/tags \\
-    (?:.*?/)?v?(\\d[\\d.]*)\\.tar\\.gz debian uupdate
+    (?:.*?/)?\@ANY_VERSION\@\@ARCHIVE_EXT\@ debian uupdate
 EOT
     } else {
         $watch_file_content = "version=4\nopts=\"mode=git\" "
           . $upstream_url
-          . " refs/tags/v([\\d\\.\\d\\.]+) debian\n";
+          . " refs/tags/\@ANY_VERSION\@ debian\n";
     }
 
     my $fh = $self->_file_w( $self->debian_file("watch") );
